models

package
v0.0.0-...-95a4c08 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 31, 2024 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ServiceEnv

type ServiceEnv struct {
	Name              string // name of environment where this service is running
	Port              string // port on which this service runs, defaults to DefaultPort
	DBName            string // name of the database
	PrintQueries      bool   // should we print the DB queries that are triggered through this service, defaults to false
	MongoVaultSideCar string // path to find the mongo sidecar file
	DisableAuth       bool   // disables authentication , added to make local development/testing easy
	LogLevel          string // logger level for the service
}

type ServiceInfo

type ServiceInfo struct {
	Name        string
	UpTime      string
	Environment string
	Version     string
}

Directories

Path Synopsis

Jump to